@@ -63,6 +63,23 @@ pub struct Config {
     )]
     database_path: PathBuf,
 
+    #[structopt(
+        short,
+        long,
+        env = "PICTRS_AGGREGATOR_SLED_CACHE_CAPACITY",
+        default_value = "67108864",
+        help = "The amount of RAM, in bytes, that sled is allowed to consume. Increasing this value can improve performance"
+    )]
+    sled_cache_capacity: u64,
+
+    #[structopt(
+        short,
+        long,
+        env = "PICTRS_AGGREGATOR_CONSOLE_EVENT_BUFFER_SIZE",
+        help = "The number of events to buffer in console. When unset, console is disabled"
+    )]
+    console_event_buffer_size: Option<usize>,
+
     #[structopt(
         short,
         long,
@@ -81,6 +98,14 @@ impl Config {
         &self.database_path
     }
 
+    pub fn sled_cache_capacity(&self) -> u64 {
+        self.sled_cache_capacity
+    }
+
+    pub fn console_event_buffer_size(&self) -> Option<usize> {
+        self.console_event_buffer_size
+    }
+
     pub fn bind_address(&self) -> SocketAddr {
         self.addr
     }
