@@ -1,6 +1,5 @@
 use actix_web::{App, HttpServer};
 use awc::Client;
-#[cfg(feature = "console")]
 use console_subscriber::ConsoleLayer;
 use opentelemetry::{
     sdk::{propagation::TraceContextPropagator, Resource},
@@ -15,7 +14,8 @@ use tracing_awc::Tracing;
 use tracing_error::ErrorLayer;
 use tracing_log::LogTracer;
 use tracing_subscriber::{
-    filter::Targets, fmt::format::FmtSpan, layer::SubscriberExt, Layer, Registry,
+    filter::Targets, fmt::format::FmtSpan, layer::SubscriberExt, registry::LookupSpan, Layer,
+    Registry,
 };
 use url::Url;
 
@@ -23,12 +23,18 @@ use url::Url;
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let config = pict_rs_aggregator::Config::from_args();
 
-    init_logger(config.opentelemetry_url())?;
+    init_logger(
+        config.opentelemetry_url(),
+        config.console_event_buffer_size(),
+    )?;
 
     let mut db_path = config.db_path().to_owned();
     db_path.push("sled");
     db_path.push("db-0-34");
-    let db = sled::open(db_path)?;
+    let db = sled::Config::new()
+        .path(db_path)
+        .cache_capacity(config.sled_cache_capacity())
+        .open()?;
     let bind_address = config.bind_address();
     let state = pict_rs_aggregator::state(config, "", db)?;
 
@@ -50,7 +56,10 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     Ok(())
 }
 
-fn init_logger(opentelemetry_url: Option<&Url>) -> Result<(), Box<dyn std::error::Error>> {
+fn init_logger(
+    opentelemetry_url: Option<&Url>,
+    console_event_buffer_size: Option<usize>,
+) -> Result<(), Box<dyn std::error::Error>> {
     LogTracer::init()?;
 
     opentelemetry::global::set_text_map_propagator(TraceContextPropagator::new());
@@ -63,20 +72,34 @@ fn init_logger(opentelemetry_url: Option<&Url>) -> Result<(), Box<dyn std::error
         .with_span_events(FmtSpan::NEW | FmtSpan::CLOSE)
         .with_filter(targets.clone());
 
-    #[cfg(feature = "console")]
-    let console_layer = ConsoleLayer::builder()
-        .with_default_env()
-        .server_addr(([0, 0, 0, 0], 6669))
-        .event_buffer_capacity(1024 * 1024)
-        .spawn();
-
     let subscriber = Registry::default()
         .with(format_layer)
         .with(ErrorLayer::default());
 
-    #[cfg(feature = "console")]
-    let subscriber = subscriber.with(console_layer);
+    if let Some(buffer_size) = console_event_buffer_size {
+        let console_layer = ConsoleLayer::builder()
+            .with_default_env()
+            .server_addr(([0, 0, 0, 0], 6669))
+            .event_buffer_capacity(buffer_size)
+            .spawn();
 
+        let subscriber = subscriber.with(console_layer);
+
+        init_subscriber(subscriber, targets, opentelemetry_url)
+    } else {
+        init_subscriber(subscriber, targets, opentelemetry_url)
+    }
+}
+
+fn init_subscriber<S>(
+    subscriber: S,
+    targets: Targets,
+    opentelemetry_url: Option<&Url>,
+) -> Result<(), Box<dyn std::error::Error>>
+where
+    S: SubscriberExt + Send + Sync,
+    for<'a> S: LookupSpan<'a>,
+{
     if let Some(url) = opentelemetry_url {
         let tracer =
             opentelemetry_otlp::new_pipeline()
